@@ -2,7 +2,10 @@ from DateTime import DateTime
 from kss.core import kssaction, KSSView
 from zope.event import notify
 from Products.Archetypes.event import ObjectInitializedEvent
+from Products.CMFCore.utils import getToolByName
+from zope.i18n import translate
 
+from plonehrm.contracts import ContractsMessageFactory as _
 
 class ContractKssView(KSSView):
     """ Class managing KSS actions for the contract viewlet.
@@ -33,10 +36,20 @@ class ContractKssView(KSSView):
         selector = core.getHtmlIdSelector('plonehrmContractViewlet')
         core.replaceHTML(selector, rendered)
 
+    @property
+    def lang(self):
+        props = getToolByName(self.context, 'portal_properties')
+        return props.site_properties.getProperty('default_language')     
+
     @kssaction
-    def show_list(self):
+    def show_list(self, hide_status=True):
         """ Shows the contract list in the viewlet.
         """
+        
+        #Hides the previous status message.
+        if hide_status:
+            self.getCommandSet('plone').issuePortalMessage('')
+
         self.replace_viewlet('list')
 
     @kssaction
@@ -77,6 +90,14 @@ class ContractKssView(KSSView):
                 selector = core.getHtmlIdSelector(
                     'contract_viewlet_settings_baddate_error')
                 core.setAttribute(selector, 'class', 'errormessage')
+
+                # Show error status message
+                message = translate(_(u'msg_error_saving_settings',
+                                      u'Errors have been found when saving settings'),
+                                    target_language=self.lang)
+                self.getCommandSet('plone').issuePortalMessage(message,
+                                                               msgtype='Error')
+                
                 return
 
             if date and not date.isPast():
@@ -84,13 +105,28 @@ class ContractKssView(KSSView):
                 selector = core.getHtmlIdSelector(
                     'contract_viewlet_settings_pastdate_error')
                 core.setAttribute(selector, 'class', 'errormessage')
+
+                message = translate(_(u'msg_error_saving_settings',
+                                      u'Errors have been found when saving settings'),
+                                    target_language=self.lang)
+                self.getCommandSet('plone').issuePortalMessage(message,
+                                                               msgtype='Error')
                 return
         else:
             date = None
 
         # Save the date and display the contract list again.
         self.context.setWorkStartDate(date)
-        self.show_list()
+
+        if date is None:
+            message = ''
+        else:
+            message = translate(_(u'msg_settings_savec',
+                                  u'Settings have been saved'),
+                                target_language=self.lang)
+
+        self.getCommandSet('plone').issuePortalMessage(message)
+        self.show_list(hide_status=False)
 
     def _validate_field(self, value, errormsg, type='int', errors = []):
         """ This method tries to cast value into the asked type.
@@ -197,6 +233,18 @@ class ContractKssView(KSSView):
             core.setAttribute(selector, 'class', 'errormessage')
 
         if len(errors) > 0:
+            if is_contract:
+                message = translate(_(u'msg_error_contract',
+                                      u'Errors were found while creating the contract'),
+                                target_language=self.lang)
+            else:
+                message = translate(_(u'msg_error_letter',
+                                      u'Errors were found while creating the letter'),
+                                target_language=self.lang)
+                
+            self.getCommandSet('plone').issuePortalMessage(message,
+                                                           msgtype='Error')
+            
             return
 
         # If no error has been found, we create the contract and display
@@ -229,4 +277,15 @@ class ContractKssView(KSSView):
         contract._renameAfterCreation()
         notify(ObjectInitializedEvent(contract))
 
-        self.show_list()
+        # Shows status message
+        if is_contract:
+            message = translate(_(u'msg_contract_added',
+                                  u'Contract added'),
+                                target_language=self.lang)
+        else:
+            message = translate(_(u'msg_letter_added',
+                                  u'Letter added'),
+                                target_language=self.lang)
+        self.getCommandSet('plone').issuePortalMessage(message)
+
+        self.show_list(hide_status=False)
